import pprint
import re  # noqa: F401

import six

class Task(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'task_type': 'str',
        'status': 'str',
        'input_data': 'dict(str, object)',
        'reference_task_name': 'str',
        'retry_count': 'int',
        'seq': 'int',
        'correlation_id': 'str',
        'poll_count': 'int',
        'task_def_name': 'str',
        'scheduled_time': 'int',
        'start_time': 'int',
        'end_time': 'int',
        'update_time': 'int',
        'start_delay_in_seconds': 'int',
        'retried_task_id': 'str',
        'retried': 'bool',
        'executed': 'bool',
        'callback_from_worker': 'bool',
        'response_timeout_seconds': 'int',
        'workflow_instance_id': 'str',
        'workflow_type': 'str',
        'task_id': 'str',
        'reason_for_incompletion': 'str',
        'callback_after_seconds': 'int',
        'worker_id': 'str',
        'output_data': 'dict(str, object)',
        'workflow_task': 'WorkflowTask',
        'domain': 'str',
        'rate_limit_per_frequency': 'int',
        'rate_limit_frequency_in_seconds': 'int',
        'external_input_payload_storage_path': 'str',
        'external_output_payload_storage_path': 'str',
        'workflow_priority': 'int',
        'execution_name_space': 'str',
        'isolation_group_id': 'str',
        'iteration': 'int',
        'sub_workflow_id': 'str',
        'subworkflow_changed': 'bool',
        'loop_over_task': 'bool',
        'task_definition': 'TaskDef',
        'queue_wait_time': 'int'
    }

    attribute_map = {
        'task_type': 'taskType',
        'status': 'status',
        'input_data': 'inputData',
        'reference_task_name': 'referenceTaskName',
        'retry_count': 'retryCount',
        'seq': 'seq',
        'correlation_id': 'correlationId',
        'poll_count': 'pollCount',
        'task_def_name': 'taskDefName',
        'scheduled_time': 'scheduledTime',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'update_time': 'updateTime',
        'start_delay_in_seconds': 'startDelayInSeconds',
        'retried_task_id': 'retriedTaskId',
        'retried': 'retried',
        'executed': 'executed',
        'callback_from_worker': 'callbackFromWorker',
        'response_timeout_seconds': 'responseTimeoutSeconds',
        'workflow_instance_id': 'workflowInstanceId',
        'workflow_type': 'workflowType',
        'task_id': 'taskId',
        'reason_for_incompletion': 'reasonForIncompletion',
        'callback_after_seconds': 'callbackAfterSeconds',
        'worker_id': 'workerId',
        'output_data': 'outputData',
        'workflow_task': 'workflowTask',
        'domain': 'domain',
        'rate_limit_per_frequency': 'rateLimitPerFrequency',
        'rate_limit_frequency_in_seconds': 'rateLimitFrequencyInSeconds',
        'external_input_payload_storage_path': 'externalInputPayloadStoragePath',
        'external_output_payload_storage_path': 'externalOutputPayloadStoragePath',
        'workflow_priority': 'workflowPriority',
        'execution_name_space': 'executionNameSpace',
        'isolation_group_id': 'isolationGroupId',
        'iteration': 'iteration',
        'sub_workflow_id': 'subWorkflowId',
        'subworkflow_changed': 'subworkflowChanged',
        'loop_over_task': 'loopOverTask',
        'task_definition': 'taskDefinition',
        'queue_wait_time': 'queueWaitTime'
    }

    def __init__(self, task_type=None, status=None, input_data=None, reference_task_name=None, retry_count=None, seq=None, correlation_id=None, poll_count=None, task_def_name=None, scheduled_time=None, start_time=None, end_time=None, update_time=None, start_delay_in_seconds=None, retried_task_id=None, retried=None, executed=None, callback_from_worker=None, response_timeout_seconds=None, workflow_instance_id=None, workflow_type=None, task_id=None, reason_for_incompletion=None, callback_after_seconds=None, worker_id=None, output_data=None, workflow_task=None, domain=None, rate_limit_per_frequency=None, rate_limit_frequency_in_seconds=None, external_input_payload_storage_path=None, external_output_payload_storage_path=None, workflow_priority=None, execution_name_space=None, isolation_group_id=None, iteration=None, sub_workflow_id=None, subworkflow_changed=None, loop_over_task=None, task_definition=None, queue_wait_time=None):  # noqa: E501
        """Task - a model defined in Swagger"""  # noqa: E501
        self._task_type = None
        self._status = None
        self._input_data = None
        self._reference_task_name = None
        self._retry_count = None
        self._seq = None
        self._correlation_id = None
        self._poll_count = None
        self._task_def_name = None
        self._scheduled_time = None
        self._start_time = None
        self._end_time = None
        self._update_time = None
        self._start_delay_in_seconds = None
        self._retried_task_id = None
        self._retried = None
        self._executed = None
        self._callback_from_worker = None
        self._response_timeout_seconds = None
        self._workflow_instance_id = None
        self._workflow_type = None
        self._task_id = None
        self._reason_for_incompletion = None
        self._callback_after_seconds = None
        self._worker_id = None
        self._output_data = None
        self._workflow_task = None
        self._domain = None
        self._rate_limit_per_frequency = None
        self._rate_limit_frequency_in_seconds = None
        self._external_input_payload_storage_path = None
        self._external_output_payload_storage_path = None
        self._workflow_priority = None
        self._execution_name_space = None
        self._isolation_group_id = None
        self._iteration = None
        self._sub_workflow_id = None
        self._subworkflow_changed = None
        self._loop_over_task = None
        self._task_definition = None
        self._queue_wait_time = None
        self.discriminator = None
        if task_type is not None:
            self.task_type = task_type
        if status is not None:
            self.status = status
        if input_data is not None:
            self.input_data = input_data
        if reference_task_name is not None:
            self.reference_task_name = reference_task_name
        if retry_count is not None:
            self.retry_count = retry_count
        if seq is not None:
            self.seq = seq
        if correlation_id is not None:
            self.correlation_id = correlation_id
        if poll_count is not None:
            self.poll_count = poll_count
        if task_def_name is not None:
            self.task_def_name = task_def_name
        if scheduled_time is not None:
            self.scheduled_time = scheduled_time
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if update_time is not None:
            self.update_time = update_time
        if start_delay_in_seconds is not None:
            self.start_delay_in_seconds = start_delay_in_seconds
        if retried_task_id is not None:
            self.retried_task_id = retried_task_id
        if retried is not None:
            self.retried = retried
        if executed is not None:
            self.executed = executed
        if callback_from_worker is not None:
            self.callback_from_worker = callback_from_worker
        if response_timeout_seconds is not None:
            self.response_timeout_seconds = response_timeout_seconds
        if workflow_instance_id is not None:
            self.workflow_instance_id = workflow_instance_id
        if workflow_type is not None:
            self.workflow_type = workflow_type
        if task_id is not None:
            self.task_id = task_id
        if reason_for_incompletion is not None:
            self.reason_for_incompletion = reason_for_incompletion
        if callback_after_seconds is not None:
            self.callback_after_seconds = callback_after_seconds
        if worker_id is not None:
            self.worker_id = worker_id
        if output_data is not None:
            self.output_data = output_data
        if workflow_task is not None:
            self.workflow_task = workflow_task
        if domain is not None:
            self.domain = domain
        if rate_limit_per_frequency is not None:
            self.rate_limit_per_frequency = rate_limit_per_frequency
        if rate_limit_frequency_in_seconds is not None:
            self.rate_limit_frequency_in_seconds = rate_limit_frequency_in_seconds
        if external_input_payload_storage_path is not None:
            self.external_input_payload_storage_path = external_input_payload_storage_path
        if external_output_payload_storage_path is not None:
            self.external_output_payload_storage_path = external_output_payload_storage_path
        if workflow_priority is not None:
            self.workflow_priority = workflow_priority
        if execution_name_space is not None:
            self.execution_name_space = execution_name_space
        if isolation_group_id is not None:
            self.isolation_group_id = isolation_group_id
        if iteration is not None:
            self.iteration = iteration
        if sub_workflow_id is not None:
            self.sub_workflow_id = sub_workflow_id
        if subworkflow_changed is not None:
            self.subworkflow_changed = subworkflow_changed
        if loop_over_task is not None:
            self.loop_over_task = loop_over_task
        if task_definition is not None:
            self.task_definition = task_definition
        if queue_wait_time is not None:
            self.queue_wait_time = queue_wait_time

    @property
    def task_type(self):
        """Gets the task_type of this Task.  # noqa: E501


        :return: The task_type of this Task.  # noqa: E501
        :rtype: str
        """
        return self._task_type

    @task_type.setter
    def task_type(self, task_type):
        """Sets the task_type of this Task.


        :param task_type: The task_type of this Task.  # noqa: E501
        :type: str
        """

        self._task_type = task_type

    @property
    def status(self):
        """Gets the status of this Task.  # noqa: E501


        :return: The status of this Task.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Task.


        :param status: The status of this Task.  # noqa: E501
        :type: str
        """
        allowed_values = ["IN_PROGRESS", "CANCELED", "FAILED", "FAILED_WITH_TERMINAL_ERROR", "COMPLETED", "COMPLETED_WITH_ERRORS", "SCHEDULED", "TIMED_OUT", "SKIPPED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def input_data(self):
        """Gets the input_data of this Task.  # noqa: E501


        :return: The input_data of this Task.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._input_data

    @input_data.setter
    def input_data(self, input_data):
        """Sets the input_data of this Task.


        :param input_data: The input_data of this Task.  # noqa: E501
        :type: dict(str, object)
        """

        self._input_data = input_data

    @property
    def reference_task_name(self):
        """Gets the reference_task_name of this Task.  # noqa: E501


        :return: The reference_task_name of this Task.  # noqa: E501
        :rtype: str
        """
        return self._reference_task_name

    @reference_task_name.setter
    def reference_task_name(self, reference_task_name):
        """Sets the reference_task_name of this Task.


        :param reference_task_name: The reference_task_name of this Task.  # noqa: E501
        :type: str
        """

        self._reference_task_name = reference_task_name

    @property
    def retry_count(self):
        """Gets the retry_count of this Task.  # noqa: E501


        :return: The retry_count of this Task.  # noqa: E501
        :rtype: int
        """
        return self._retry_count

    @retry_count.setter
    def retry_count(self, retry_count):
        """Sets the retry_count of this Task.


        :param retry_count: The retry_count of this Task.  # noqa: E501
        :type: int
        """

        self._retry_count = retry_count

    @property
    def seq(self):
        """Gets the seq of this Task.  # noqa: E501


        :return: The seq of this Task.  # noqa: E501
        :rtype: int
        """
        return self._seq

    @seq.setter
    def seq(self, seq):
        """Sets the seq of this Task.


        :param seq: The seq of this Task.  # noqa: E501
        :type: int
        """

        self._seq = seq

    @property
    def correlation_id(self):
        """Gets the correlation_id of this Task.  # noqa: E501


        :return: The correlation_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """Sets the correlation_id of this Task.


        :param correlation_id: The correlation_id of this Task.  # noqa: E501
        :type: str
        """

        self._correlation_id = correlation_id

    @property
    def poll_count(self):
        """Gets the poll_count of this Task.  # noqa: E501


        :return: The poll_count of this Task.  # noqa: E501
        :rtype: int
        """
        return self._poll_count

    @poll_count.setter
    def poll_count(self, poll_count):
        """Sets the poll_count of this Task.


        :param poll_count: The poll_count of this Task.  # noqa: E501
        :type: int
        """

        self._poll_count = poll_count

    @property
    def task_def_name(self):
        """Gets the task_def_name of this Task.  # noqa: E501


        :return: The task_def_name of this Task.  # noqa: E501
        :rtype: str
        """
        return self._task_def_name

    @task_def_name.setter
    def task_def_name(self, task_def_name):
        """Sets the task_def_name of this Task.


        :param task_def_name: The task_def_name of this Task.  # noqa: E501
        :type: str
        """

        self._task_def_name = task_def_name

    @property
    def scheduled_time(self):
        """Gets the scheduled_time of this Task.  # noqa: E501


        :return: The scheduled_time of this Task.  # noqa: E501
        :rtype: int
        """
        return self._scheduled_time

    @scheduled_time.setter
    def scheduled_time(self, scheduled_time):
        """Sets the scheduled_time of this Task.


        :param scheduled_time: The scheduled_time of this Task.  # noqa: E501
        :type: int
        """

        self._scheduled_time = scheduled_time

    @property
    def start_time(self):
        """Gets the start_time of this Task.  # noqa: E501


        :return: The start_time of this Task.  # noqa: E501
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this Task.


        :param start_time: The start_time of this Task.  # noqa: E501
        :type: int
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this Task.  # noqa: E501


        :return: The end_time of this Task.  # noqa: E501
        :rtype: int
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this Task.


        :param end_time: The end_time of this Task.  # noqa: E501
        :type: int
        """

        self._end_time = end_time

    @property
    def update_time(self):
        """Gets the update_time of this Task.  # noqa: E501


        :return: The update_time of this Task.  # noqa: E501
        :rtype: int
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Task.


        :param update_time: The update_time of this Task.  # noqa: E501
        :type: int
        """

        self._update_time = update_time

    @property
    def start_delay_in_seconds(self):
        """Gets the start_delay_in_seconds of this Task.  # noqa: E501


        :return: The start_delay_in_seconds of this Task.  # noqa: E501
        :rtype: int
        """
        return self._start_delay_in_seconds

    @start_delay_in_seconds.setter
    def start_delay_in_seconds(self, start_delay_in_seconds):
        """Sets the start_delay_in_seconds of this Task.


        :param start_delay_in_seconds: The start_delay_in_seconds of this Task.  # noqa: E501
        :type: int
        """

        self._start_delay_in_seconds = start_delay_in_seconds

    @property
    def retried_task_id(self):
        """Gets the retried_task_id of this Task.  # noqa: E501


        :return: The retried_task_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._retried_task_id

    @retried_task_id.setter
    def retried_task_id(self, retried_task_id):
        """Sets the retried_task_id of this Task.


        :param retried_task_id: The retried_task_id of this Task.  # noqa: E501
        :type: str
        """

        self._retried_task_id = retried_task_id

    @property
    def retried(self):
        """Gets the retried of this Task.  # noqa: E501


        :return: The retried of this Task.  # noqa: E501
        :rtype: bool
        """
        return self._retried

    @retried.setter
    def retried(self, retried):
        """Sets the retried of this Task.


        :param retried: The retried of this Task.  # noqa: E501
        :type: bool
        """

        self._retried = retried

    @property
    def executed(self):
        """Gets the executed of this Task.  # noqa: E501


        :return: The executed of this Task.  # noqa: E501
        :rtype: bool
        """
        return self._executed

    @executed.setter
    def executed(self, executed):
        """Sets the executed of this Task.


        :param executed: The executed of this Task.  # noqa: E501
        :type: bool
        """

        self._executed = executed

    @property
    def callback_from_worker(self):
        """Gets the callback_from_worker of this Task.  # noqa: E501


        :return: The callback_from_worker of this Task.  # noqa: E501
        :rtype: bool
        """
        return self._callback_from_worker

    @callback_from_worker.setter
    def callback_from_worker(self, callback_from_worker):
        """Sets the callback_from_worker of this Task.


        :param callback_from_worker: The callback_from_worker of this Task.  # noqa: E501
        :type: bool
        """

        self._callback_from_worker = callback_from_worker

    @property
    def response_timeout_seconds(self):
        """Gets the response_timeout_seconds of this Task.  # noqa: E501


        :return: The response_timeout_seconds of this Task.  # noqa: E501
        :rtype: int
        """
        return self._response_timeout_seconds

    @response_timeout_seconds.setter
    def response_timeout_seconds(self, response_timeout_seconds):
        """Sets the response_timeout_seconds of this Task.


        :param response_timeout_seconds: The response_timeout_seconds of this Task.  # noqa: E501
        :type: int
        """

        self._response_timeout_seconds = response_timeout_seconds

    @property
    def workflow_instance_id(self):
        """Gets the workflow_instance_id of this Task.  # noqa: E501


        :return: The workflow_instance_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._workflow_instance_id

    @workflow_instance_id.setter
    def workflow_instance_id(self, workflow_instance_id):
        """Sets the workflow_instance_id of this Task.


        :param workflow_instance_id: The workflow_instance_id of this Task.  # noqa: E501
        :type: str
        """

        self._workflow_instance_id = workflow_instance_id

    @property
    def workflow_type(self):
        """Gets the workflow_type of this Task.  # noqa: E501


        :return: The workflow_type of this Task.  # noqa: E501
        :rtype: str
        """
        return self._workflow_type

    @workflow_type.setter
    def workflow_type(self, workflow_type):
        """Sets the workflow_type of this Task.


        :param workflow_type: The workflow_type of this Task.  # noqa: E501
        :type: str
        """

        self._workflow_type = workflow_type

    @property
    def task_id(self):
        """Gets the task_id of this Task.  # noqa: E501


        :return: The task_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this Task.


        :param task_id: The task_id of this Task.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    @property
    def reason_for_incompletion(self):
        """Gets the reason_for_incompletion of this Task.  # noqa: E501


        :return: The reason_for_incompletion of this Task.  # noqa: E501
        :rtype: str
        """
        return self._reason_for_incompletion

    @reason_for_incompletion.setter
    def reason_for_incompletion(self, reason_for_incompletion):
        """Sets the reason_for_incompletion of this Task.


        :param reason_for_incompletion: The reason_for_incompletion of this Task.  # noqa: E501
        :type: str
        """

        self._reason_for_incompletion = reason_for_incompletion

    @property
    def callback_after_seconds(self):
        """Gets the callback_after_seconds of this Task.  # noqa: E501


        :return: The callback_after_seconds of this Task.  # noqa: E501
        :rtype: int
        """
        return self._callback_after_seconds

    @callback_after_seconds.setter
    def callback_after_seconds(self, callback_after_seconds):
        """Sets the callback_after_seconds of this Task.


        :param callback_after_seconds: The callback_after_seconds of this Task.  # noqa: E501
        :type: int
        """

        self._callback_after_seconds = callback_after_seconds

    @property
    def worker_id(self):
        """Gets the worker_id of this Task.  # noqa: E501


        :return: The worker_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._worker_id

    @worker_id.setter
    def worker_id(self, worker_id):
        """Sets the worker_id of this Task.


        :param worker_id: The worker_id of this Task.  # noqa: E501
        :type: str
        """

        self._worker_id = worker_id

    @property
    def output_data(self):
        """Gets the output_data of this Task.  # noqa: E501


        :return: The output_data of this Task.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._output_data

    @output_data.setter
    def output_data(self, output_data):
        """Sets the output_data of this Task.


        :param output_data: The output_data of this Task.  # noqa: E501
        :type: dict(str, object)
        """

        self._output_data = output_data

    @property
    def workflow_task(self):
        """Gets the workflow_task of this Task.  # noqa: E501


        :return: The workflow_task of this Task.  # noqa: E501
        :rtype: WorkflowTask
        """
        return self._workflow_task

    @workflow_task.setter
    def workflow_task(self, workflow_task):
        """Sets the workflow_task of this Task.


        :param workflow_task: The workflow_task of this Task.  # noqa: E501
        :type: WorkflowTask
        """

        self._workflow_task = workflow_task

    @property
    def domain(self):
        """Gets the domain of this Task.  # noqa: E501


        :return: The domain of this Task.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this Task.


        :param domain: The domain of this Task.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def rate_limit_per_frequency(self):
        """Gets the rate_limit_per_frequency of this Task.  # noqa: E501


        :return: The rate_limit_per_frequency of this Task.  # noqa: E501
        :rtype: int
        """
        return self._rate_limit_per_frequency

    @rate_limit_per_frequency.setter
    def rate_limit_per_frequency(self, rate_limit_per_frequency):
        """Sets the rate_limit_per_frequency of this Task.


        :param rate_limit_per_frequency: The rate_limit_per_frequency of this Task.  # noqa: E501
        :type: int
        """

        self._rate_limit_per_frequency = rate_limit_per_frequency

    @property
    def rate_limit_frequency_in_seconds(self):
        """Gets the rate_limit_frequency_in_seconds of this Task.  # noqa: E501


        :return: The rate_limit_frequency_in_seconds of this Task.  # noqa: E501
        :rtype: int
        """
        return self._rate_limit_frequency_in_seconds

    @rate_limit_frequency_in_seconds.setter
    def rate_limit_frequency_in_seconds(self, rate_limit_frequency_in_seconds):
        """Sets the rate_limit_frequency_in_seconds of this Task.


        :param rate_limit_frequency_in_seconds: The rate_limit_frequency_in_seconds of this Task.  # noqa: E501
        :type: int
        """

        self._rate_limit_frequency_in_seconds = rate_limit_frequency_in_seconds

    @property
    def external_input_payload_storage_path(self):
        """Gets the external_input_payload_storage_path of this Task.  # noqa: E501


        :return: The external_input_payload_storage_path of this Task.  # noqa: E501
        :rtype: str
        """
        return self._external_input_payload_storage_path

    @external_input_payload_storage_path.setter
    def external_input_payload_storage_path(self, external_input_payload_storage_path):
        """Sets the external_input_payload_storage_path of this Task.


        :param external_input_payload_storage_path: The external_input_payload_storage_path of this Task.  # noqa: E501
        :type: str
        """

        self._external_input_payload_storage_path = external_input_payload_storage_path

    @property
    def external_output_payload_storage_path(self):
        """Gets the external_output_payload_storage_path of this Task.  # noqa: E501


        :return: The external_output_payload_storage_path of this Task.  # noqa: E501
        :rtype: str
        """
        return self._external_output_payload_storage_path

    @external_output_payload_storage_path.setter
    def external_output_payload_storage_path(self, external_output_payload_storage_path):
        """Sets the external_output_payload_storage_path of this Task.


        :param external_output_payload_storage_path: The external_output_payload_storage_path of this Task.  # noqa: E501
        :type: str
        """

        self._external_output_payload_storage_path = external_output_payload_storage_path

    @property
    def workflow_priority(self):
        """Gets the workflow_priority of this Task.  # noqa: E501


        :return: The workflow_priority of this Task.  # noqa: E501
        :rtype: int
        """
        return self._workflow_priority

    @workflow_priority.setter
    def workflow_priority(self, workflow_priority):
        """Sets the workflow_priority of this Task.


        :param workflow_priority: The workflow_priority of this Task.  # noqa: E501
        :type: int
        """

        self._workflow_priority = workflow_priority

    @property
    def execution_name_space(self):
        """Gets the execution_name_space of this Task.  # noqa: E501


        :return: The execution_name_space of this Task.  # noqa: E501
        :rtype: str
        """
        return self._execution_name_space

    @execution_name_space.setter
    def execution_name_space(self, execution_name_space):
        """Sets the execution_name_space of this Task.


        :param execution_name_space: The execution_name_space of this Task.  # noqa: E501
        :type: str
        """

        self._execution_name_space = execution_name_space

    @property
    def isolation_group_id(self):
        """Gets the isolation_group_id of this Task.  # noqa: E501


        :return: The isolation_group_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._isolation_group_id

    @isolation_group_id.setter
    def isolation_group_id(self, isolation_group_id):
        """Sets the isolation_group_id of this Task.


        :param isolation_group_id: The isolation_group_id of this Task.  # noqa: E501
        :type: str
        """

        self._isolation_group_id = isolation_group_id

    @property
    def iteration(self):
        """Gets the iteration of this Task.  # noqa: E501


        :return: The iteration of this Task.  # noqa: E501
        :rtype: int
        """
        return self._iteration

    @iteration.setter
    def iteration(self, iteration):
        """Sets the iteration of this Task.


        :param iteration: The iteration of this Task.  # noqa: E501
        :type: int
        """

        self._iteration = iteration

    @property
    def sub_workflow_id(self):
        """Gets the sub_workflow_id of this Task.  # noqa: E501


        :return: The sub_workflow_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._sub_workflow_id

    @sub_workflow_id.setter
    def sub_workflow_id(self, sub_workflow_id):
        """Sets the sub_workflow_id of this Task.


        :param sub_workflow_id: The sub_workflow_id of this Task.  # noqa: E501
        :type: str
        """

        self._sub_workflow_id = sub_workflow_id

    @property
    def subworkflow_changed(self):
        """Gets the subworkflow_changed of this Task.  # noqa: E501


        :return: The subworkflow_changed of this Task.  # noqa: E501
        :rtype: bool
        """
        return self._subworkflow_changed

    @subworkflow_changed.setter
    def subworkflow_changed(self, subworkflow_changed):
        """Sets the subworkflow_changed of this Task.


        :param subworkflow_changed: The subworkflow_changed of this Task.  # noqa: E501
        :type: bool
        """

        self._subworkflow_changed = subworkflow_changed

    @property
    def loop_over_task(self):
        """Gets the loop_over_task of this Task.  # noqa: E501


        :return: The loop_over_task of this Task.  # noqa: E501
        :rtype: bool
        """
        return self._loop_over_task

    @loop_over_task.setter
    def loop_over_task(self, loop_over_task):
        """Sets the loop_over_task of this Task.


        :param loop_over_task: The loop_over_task of this Task.  # noqa: E501
        :type: bool
        """

        self._loop_over_task = loop_over_task

    @property
    def task_definition(self):
        """Gets the task_definition of this Task.  # noqa: E501


        :return: The task_definition of this Task.  # noqa: E501
        :rtype: TaskDef
        """
        return self._task_definition

    @task_definition.setter
    def task_definition(self, task_definition):
        """Sets the task_definition of this Task.


        :param task_definition: The task_definition of this Task.  # noqa: E501
        :type: TaskDef
        """

        self._task_definition = task_definition

    @property
    def queue_wait_time(self):
        """Gets the queue_wait_time of this Task.  # noqa: E501


        :return: The queue_wait_time of this Task.  # noqa: E501
        :rtype: int
        """
        return self._queue_wait_time

    @queue_wait_time.setter
    def queue_wait_time(self, queue_wait_time):
        """Sets the queue_wait_time of this Task.


        :param queue_wait_time: The queue_wait_time of this Task.  # noqa: E501
        :type: int
        """

        self._queue_wait_time = queue_wait_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Task, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Task):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import pprint
import re  # noqa: F401

import six

class WorkflowSchedule(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'cron_expression': 'str',
        'run_catchup_schedule_instances': 'bool',
        'paused': 'bool',
        'start_workflow_request': 'StartWorkflowRequest',
        'schedule_start_time': 'int',
        'schedule_end_time': 'int',
        'create_time': 'int',
        'updated_time': 'int',
        'created_by': 'str',
        'updated_by': 'str'
    }

    attribute_map = {
        'name': 'name',
        'cron_expression': 'cronExpression',
        'run_catchup_schedule_instances': 'runCatchupScheduleInstances',
        'paused': 'paused',
        'start_workflow_request': 'startWorkflowRequest',
        'schedule_start_time': 'scheduleStartTime',
        'schedule_end_time': 'scheduleEndTime',
        'create_time': 'createTime',
        'updated_time': 'updatedTime',
        'created_by': 'createdBy',
        'updated_by': 'updatedBy'
    }

    def __init__(self, name=None, cron_expression=None, run_catchup_schedule_instances=None, paused=None, start_workflow_request=None, schedule_start_time=None, schedule_end_time=None, create_time=None, updated_time=None, created_by=None, updated_by=None):  # noqa: E501
        """WorkflowSchedule - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._cron_expression = None
        self._run_catchup_schedule_instances = None
        self._paused = None
        self._start_workflow_request = None
        self._schedule_start_time = None
        self._schedule_end_time = None
        self._create_time = None
        self._updated_time = None
        self._created_by = None
        self._updated_by = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if cron_expression is not None:
            self.cron_expression = cron_expression
        if run_catchup_schedule_instances is not None:
            self.run_catchup_schedule_instances = run_catchup_schedule_instances
        if paused is not None:
            self.paused = paused
        if start_workflow_request is not None:
            self.start_workflow_request = start_workflow_request
        if schedule_start_time is not None:
            self.schedule_start_time = schedule_start_time
        if schedule_end_time is not None:
            self.schedule_end_time = schedule_end_time
        if create_time is not None:
            self.create_time = create_time
        if updated_time is not None:
            self.updated_time = updated_time
        if created_by is not None:
            self.created_by = created_by
        if updated_by is not None:
            self.updated_by = updated_by

    @property
    def name(self):
        """Gets the name of this WorkflowSchedule.  # noqa: E501


        :return: The name of this WorkflowSchedule.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowSchedule.


        :param name: The name of this WorkflowSchedule.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def cron_expression(self):
        """Gets the cron_expression of this WorkflowSchedule.  # noqa: E501


        :return: The cron_expression of this WorkflowSchedule.  # noqa: E501
        :rtype: str
        """
        return self._cron_expression

    @cron_expression.setter
    def cron_expression(self, cron_expression):
        """Sets the cron_expression of this WorkflowSchedule.


        :param cron_expression: The cron_expression of this WorkflowSchedule.  # noqa: E501
        :type: str
        """

        self._cron_expression = cron_expression

    @property
    def run_catchup_schedule_instances(self):
        """Gets the run_catchup_schedule_instances of this WorkflowSchedule.  # noqa: E501


        :return: The run_catchup_schedule_instances of this WorkflowSchedule.  # noqa: E501
        :rtype: bool
        """
        return self._run_catchup_schedule_instances

    @run_catchup_schedule_instances.setter
    def run_catchup_schedule_instances(self, run_catchup_schedule_instances):
        """Sets the run_catchup_schedule_instances of this WorkflowSchedule.


        :param run_catchup_schedule_instances: The run_catchup_schedule_instances of this WorkflowSchedule.  # noqa: E501
        :type: bool
        """

        self._run_catchup_schedule_instances = run_catchup_schedule_instances

    @property
    def paused(self):
        """Gets the paused of this WorkflowSchedule.  # noqa: E501


        :return: The paused of this WorkflowSchedule.  # noqa: E501
        :rtype: bool
        """
        return self._paused

    @paused.setter
    def paused(self, paused):
        """Sets the paused of this WorkflowSchedule.


        :param paused: The paused of this WorkflowSchedule.  # noqa: E501
        :type: bool
        """

        self._paused = paused

    @property
    def start_workflow_request(self):
        """Gets the start_workflow_request of this WorkflowSchedule.  # noqa: E501


        :return: The start_workflow_request of this WorkflowSchedule.  # noqa: E501
        :rtype: StartWorkflowRequest
        """
        return self._start_workflow_request

    @start_workflow_request.setter
    def start_workflow_request(self, start_workflow_request):
        """Sets the start_workflow_request of this WorkflowSchedule.


        :param start_workflow_request: The start_workflow_request of this WorkflowSchedule.  # noqa: E501
        :type: StartWorkflowRequest
        """

        self._start_workflow_request = start_workflow_request

    @property
    def schedule_start_time(self):
        """Gets the schedule_start_time of this WorkflowSchedule.  # noqa: E501


        :return: The schedule_start_time of this WorkflowSchedule.  # noqa: E501
        :rtype: int
        """
        return self._schedule_start_time

    @schedule_start_time.setter
    def schedule_start_time(self, schedule_start_time):
        """Sets the schedule_start_time of this WorkflowSchedule.


        :param schedule_start_time: The schedule_start_time of this WorkflowSchedule.  # noqa: E501
        :type: int
        """

        self._schedule_start_time = schedule_start_time

    @property
    def schedule_end_time(self):
        """Gets the schedule_end_time of this WorkflowSchedule.  # noqa: E501


        :return: The schedule_end_time of this WorkflowSchedule.  # noqa: E501
        :rtype: int
        """
        return self._schedule_end_time

    @schedule_end_time.setter
    def schedule_end_time(self, schedule_end_time):
        """Sets the schedule_end_time of this WorkflowSchedule.


        :param schedule_end_time: The schedule_end_time of this WorkflowSchedule.  # noqa: E501
        :type: int
        """

        self._schedule_end_time = schedule_end_time

    @property
    def create_time(self):
        """Gets the create_time of this WorkflowSchedule.  # noqa: E501


        :return: The create_time of this WorkflowSchedule.  # noqa: E501
        :rtype: int
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this WorkflowSchedule.


        :param create_time: The create_time of this WorkflowSchedule.  # noqa: E501
        :type: int
        """

        self._create_time = create_time

    @property
    def updated_time(self):
        """Gets the updated_time of this WorkflowSchedule.  # noqa: E501


        :return: The updated_time of this WorkflowSchedule.  # noqa: E501
        :rtype: int
        """
        return self._updated_time

    @updated_time.setter
    def updated_time(self, updated_time):
        """Sets the updated_time of this WorkflowSchedule.


        :param updated_time: The updated_time of this WorkflowSchedule.  # noqa: E501
        :type: int
        """

        self._updated_time = updated_time

    @property
    def created_by(self):
        """Gets the created_by of this WorkflowSchedule.  # noqa: E501


        :return: The created_by of this WorkflowSchedule.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this WorkflowSchedule.


        :param created_by: The created_by of this WorkflowSchedule.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def updated_by(self):
        """Gets the updated_by of this WorkflowSchedule.  # noqa: E501


        :return: The updated_by of this WorkflowSchedule.  # noqa: E501
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this WorkflowSchedule.


        :param updated_by: The updated_by of this WorkflowSchedule.  # noqa: E501
        :type: str
        """

        self._updated_by = updated_by

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowSchedule, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowSchedule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from abc import ABC, abstractmethod
from conductor.client.workflow.task.task import TaskInterface
from conductor.client.workflow.task.task_type import TaskType
from typing_extensions import Self


class WaitTask(TaskInterface, ABC):
    @abstractmethod
    def __init__(self, task_ref_name: str) -> Self:
        super().__init__(
            task_reference_name=task_ref_name,
            task_type=TaskType.WAIT
        )


class WaitForDurationTask(WaitTask):
    def __init__(self, task_ref_name: str, duration_time_seconds: int) -> Self:
        super().__init__(task_ref_name)
        self.input_parameters = {
            "duration": str(duration_time_seconds)
        }


class WaitUntilTask(WaitTask):
    def __init__(self, task_ref_name: str, date_time: str) -> Self:
        super().__init__(task_ref_name)
        self.input_parameters = {
            "until": date_time
        }



from conductor.client.configuration.settings.authentication_settings import AuthenticationSettings
import logging
import multiprocessing
import os


class Configuration:
    AUTH_TOKEN = None

    def __init__(
            self,
            base_url: str = "http://localhost:8080",
            debug: bool = False,
            authentication_settings: AuthenticationSettings = None,
            server_api_url: str = None,
    ):
        if server_api_url != None:
            self.host = server_api_url
        else:
            self.host = base_url + '/api/'

        self.temp_folder_path = None

        self.authentication_settings = authentication_settings

        # Debug switch
        self.debug = debug
        # Log format
        self.logger_format = '%(asctime)s %(name)-12s %(levelname)-8s %(message)s'

        # SSL/TLS verification
        # Set this to false to skip verifying SSL certificate when calling API
        # from https server.
        self.verify_ssl = True
        # Set this to customize the certificate file to verify the peer.
        self.ssl_ca_cert = None
        # client certificate file
        self.cert_file = None
        # client key file
        self.key_file = None
        # Set this to True/False to enable/disable SSL hostname verification.
        self.assert_hostname = None

        # Proxy URL
        self.proxy = None
        # Safe chars for path_param
        self.safe_chars_for_path_param = ''

    @property
    def debug(self):
        """Debug status

        :param value: The debug status, True or False.
        :type: bool
        """
        return self.__debug

    @debug.setter
    def debug(self, value):
        """Debug status

        :param value: The debug status, True or False.
        :type: bool
        """
        self.__debug = value
        if self.__debug:
            self.__log_level = logging.DEBUG
        else:
            self.__log_level = logging.INFO

    @property
    def logger_format(self):
        """The logger format.

        The logger_formatter will be updated when sets logger_format.

        :param value: The format string.
        :type: str
        """
        return self.__logger_format

    @logger_format.setter
    def logger_format(self, value):
        """The logger format.

        The logger_formatter will be updated when sets logger_format.

        :param value: The format string.
        :type: str
        """
        self.__logger_format = value

    def apply_logging_config(self):
        logging.basicConfig(
            format=self.logger_format,
            level=self.__log_level
        )

    @staticmethod
    def get_logging_formatted_name(name):
        return f'[{os.getpid()}] {name}'

    def update_token(self, token: str) -> None:
        self.AUTH_TOKEN = token



from conductor.client.event.queue.queue_worker_configuration import QueueWorkerConfiguration

from abc import ABC
from typing import Any, Dict


class QueueConfiguration(ABC):
    WORKER_CONSUMER_KEY = "consumer"
    WORKER_PRODUCER_KEY = "producer"

    def __init__(self, queue_name: str, queue_type: str):
        self.queue_name = queue_name
        self.queue_type = queue_type
        self.worker_configuration = {}

    def add_consumer(self, worker_configuration: QueueWorkerConfiguration) -> None:
        self.worker_configuration[self.WORKER_CONSUMER_KEY] = worker_configuration

    def add_producer(self, worker_configuration: QueueWorkerConfiguration) -> None:
        self.worker_configuration[self.WORKER_PRODUCER_KEY] = worker_configuration

    def get_worker_configuration(self) -> Dict[str, Any]:
        raise NotImplementedError



from conductor.client.http.models.workflow_task import WorkflowTask
from conductor.client.workflow.task.task import TaskInterface, get_task_interface_list_as_workflow_task_list
from conductor.client.workflow.task.task_type import TaskType
from copy import deepcopy
from typing import List
from typing_extensions import Self


def get_for_loop_condition(task_ref_name: str, iterations: int) -> str:
    return f"if ( $.{task_ref_name}.iteration < $.{iterations} ) {{ true; }} else {{ false; }}"


class DoWhileTask(TaskInterface):
    # termination_condition is a Javascript expression that evaluates to True or False
    def __init__(self, task_ref_name: str, termination_condition: str, tasks: List[TaskInterface]) -> Self:
        super().__init__(
            task_reference_name=task_ref_name,
            task_type=TaskType.DO_WHILE,
        )
        self._loop_condition = deepcopy(termination_condition)
        self._loop_over = deepcopy(tasks)

    def to_workflow_task(self) -> WorkflowTask:
        workflow = super().to_workflow_task()
        workflow.loop_condition = self._loop_condition
        workflow.loop_over = get_task_interface_list_as_workflow_task_list(
            self._loop_over,
        )
        return workflow


class LoopTask(DoWhileTask):
    def __init__(self, task_ref_name: str, iterations: int, tasks: List[TaskInterface]) -> Self:
        super().__init__(
            task_ref_name=task_ref_name,
            termination_condition=get_for_loop_condition(
                task_ref_name, iterations,
            ),
            tasks=tasks,
        )



import pprint
import re  # noqa: F401

import six

class TaskDef(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'owner_app': 'str',
        'create_time': 'int',
        'update_time': 'int',
        'created_by': 'str',
        'updated_by': 'str',
        'name': 'str',
        'description': 'str',
        'retry_count': 'int',
        'timeout_seconds': 'int',
        'input_keys': 'list[str]',
        'output_keys': 'list[str]',
        'timeout_policy': 'str',
        'retry_logic': 'str',
        'retry_delay_seconds': 'int',
        'response_timeout_seconds': 'int',
        'concurrent_exec_limit': 'int',
        'input_template': 'dict(str, object)',
        'rate_limit_per_frequency': 'int',
        'rate_limit_frequency_in_seconds': 'int',
        'isolation_group_id': 'str',
        'execution_name_space': 'str',
        'owner_email': 'str',
        'poll_timeout_seconds': 'int',
        'backoff_scale_factor': 'int'
    }

    attribute_map = {
        'owner_app': 'ownerApp',
        'create_time': 'createTime',
        'update_time': 'updateTime',
        'created_by': 'createdBy',
        'updated_by': 'updatedBy',
        'name': 'name',
        'description': 'description',
        'retry_count': 'retryCount',
        'timeout_seconds': 'timeoutSeconds',
        'input_keys': 'inputKeys',
        'output_keys': 'outputKeys',
        'timeout_policy': 'timeoutPolicy',
        'retry_logic': 'retryLogic',
        'retry_delay_seconds': 'retryDelaySeconds',
        'response_timeout_seconds': 'responseTimeoutSeconds',
        'concurrent_exec_limit': 'concurrentExecLimit',
        'input_template': 'inputTemplate',
        'rate_limit_per_frequency': 'rateLimitPerFrequency',
        'rate_limit_frequency_in_seconds': 'rateLimitFrequencyInSeconds',
        'isolation_group_id': 'isolationGroupId',
        'execution_name_space': 'executionNameSpace',
        'owner_email': 'ownerEmail',
        'poll_timeout_seconds': 'pollTimeoutSeconds',
        'backoff_scale_factor': 'backoffScaleFactor'
    }

    def __init__(self, owner_app=None, create_time=None, update_time=None, created_by=None, updated_by=None, name=None, description=None, retry_count=None, timeout_seconds=None, input_keys=None, output_keys=None, timeout_policy=None, retry_logic=None, retry_delay_seconds=None, response_timeout_seconds=None, concurrent_exec_limit=None, input_template=None, rate_limit_per_frequency=None, rate_limit_frequency_in_seconds=None, isolation_group_id=None, execution_name_space=None, owner_email=None, poll_timeout_seconds=None, backoff_scale_factor=None):  # noqa: E501
        """TaskDef - a model defined in Swagger"""  # noqa: E501
        self._owner_app = None
        self._create_time = None
        self._update_time = None
        self._created_by = None
        self._updated_by = None
        self._name = None
        self._description = None
        self._retry_count = None
        self._timeout_seconds = None
        self._input_keys = None
        self._output_keys = None
        self._timeout_policy = None
        self._retry_logic = None
        self._retry_delay_seconds = None
        self._response_timeout_seconds = None
        self._concurrent_exec_limit = None
        self._input_template = None
        self._rate_limit_per_frequency = None
        self._rate_limit_frequency_in_seconds = None
        self._isolation_group_id = None
        self._execution_name_space = None
        self._owner_email = None
        self._poll_timeout_seconds = None
        self._backoff_scale_factor = None
        self.discriminator = None
        if owner_app is not None:
            self.owner_app = owner_app
        if create_time is not None:
            self.create_time = create_time
        if update_time is not None:
            self.update_time = update_time
        if created_by is not None:
            self.created_by = created_by
        if updated_by is not None:
            self.updated_by = updated_by
        self.name = name
        if description is not None:
            self.description = description
        if retry_count is not None:
            self.retry_count = retry_count
        self.timeout_seconds = timeout_seconds
        if input_keys is not None:
            self.input_keys = input_keys
        if output_keys is not None:
            self.output_keys = output_keys
        if timeout_policy is not None:
            self.timeout_policy = timeout_policy
        if retry_logic is not None:
            self.retry_logic = retry_logic
        if retry_delay_seconds is not None:
            self.retry_delay_seconds = retry_delay_seconds
        if response_timeout_seconds is not None:
            self.response_timeout_seconds = response_timeout_seconds
        if concurrent_exec_limit is not None:
            self.concurrent_exec_limit = concurrent_exec_limit
        if input_template is not None:
            self.input_template = input_template
        if rate_limit_per_frequency is not None:
            self.rate_limit_per_frequency = rate_limit_per_frequency
        if rate_limit_frequency_in_seconds is not None:
            self.rate_limit_frequency_in_seconds = rate_limit_frequency_in_seconds
        if isolation_group_id is not None:
            self.isolation_group_id = isolation_group_id
        if execution_name_space is not None:
            self.execution_name_space = execution_name_space
        if owner_email is not None:
            self.owner_email = owner_email
        if poll_timeout_seconds is not None:
            self.poll_timeout_seconds = poll_timeout_seconds
        if backoff_scale_factor is not None:
            self.backoff_scale_factor = backoff_scale_factor

    @property
    def owner_app(self):
        """Gets the owner_app of this TaskDef.  # noqa: E501


        :return: The owner_app of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._owner_app

    @owner_app.setter
    def owner_app(self, owner_app):
        """Sets the owner_app of this TaskDef.


        :param owner_app: The owner_app of this TaskDef.  # noqa: E501
        :type: str
        """

        self._owner_app = owner_app

    @property
    def create_time(self):
        """Gets the create_time of this TaskDef.  # noqa: E501


        :return: The create_time of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this TaskDef.


        :param create_time: The create_time of this TaskDef.  # noqa: E501
        :type: int
        """

        self._create_time = create_time

    @property
    def update_time(self):
        """Gets the update_time of this TaskDef.  # noqa: E501


        :return: The update_time of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this TaskDef.


        :param update_time: The update_time of this TaskDef.  # noqa: E501
        :type: int
        """

        self._update_time = update_time

    @property
    def created_by(self):
        """Gets the created_by of this TaskDef.  # noqa: E501


        :return: The created_by of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this TaskDef.


        :param created_by: The created_by of this TaskDef.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def updated_by(self):
        """Gets the updated_by of this TaskDef.  # noqa: E501


        :return: The updated_by of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this TaskDef.


        :param updated_by: The updated_by of this TaskDef.  # noqa: E501
        :type: str
        """

        self._updated_by = updated_by

    @property
    def name(self):
        """Gets the name of this TaskDef.  # noqa: E501


        :return: The name of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskDef.


        :param name: The name of this TaskDef.  # noqa: E501
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """Gets the description of this TaskDef.  # noqa: E501


        :return: The description of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TaskDef.


        :param description: The description of this TaskDef.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def retry_count(self):
        """Gets the retry_count of this TaskDef.  # noqa: E501


        :return: The retry_count of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._retry_count

    @retry_count.setter
    def retry_count(self, retry_count):
        """Sets the retry_count of this TaskDef.


        :param retry_count: The retry_count of this TaskDef.  # noqa: E501
        :type: int
        """

        self._retry_count = retry_count

    @property
    def timeout_seconds(self):
        """Gets the timeout_seconds of this TaskDef.  # noqa: E501


        :return: The timeout_seconds of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._timeout_seconds

    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds):
        """Sets the timeout_seconds of this TaskDef.


        :param timeout_seconds: The timeout_seconds of this TaskDef.  # noqa: E501
        :type: int
        """
        self._timeout_seconds = timeout_seconds

    @property
    def input_keys(self):
        """Gets the input_keys of this TaskDef.  # noqa: E501


        :return: The input_keys of this TaskDef.  # noqa: E501
        :rtype: list[str]
        """
        return self._input_keys

    @input_keys.setter
    def input_keys(self, input_keys):
        """Sets the input_keys of this TaskDef.


        :param input_keys: The input_keys of this TaskDef.  # noqa: E501
        :type: list[str]
        """

        self._input_keys = input_keys

    @property
    def output_keys(self):
        """Gets the output_keys of this TaskDef.  # noqa: E501


        :return: The output_keys of this TaskDef.  # noqa: E501
        :rtype: list[str]
        """
        return self._output_keys

    @output_keys.setter
    def output_keys(self, output_keys):
        """Sets the output_keys of this TaskDef.


        :param output_keys: The output_keys of this TaskDef.  # noqa: E501
        :type: list[str]
        """

        self._output_keys = output_keys

    @property
    def timeout_policy(self):
        """Gets the timeout_policy of this TaskDef.  # noqa: E501


        :return: The timeout_policy of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._timeout_policy

    @timeout_policy.setter
    def timeout_policy(self, timeout_policy):
        """Sets the timeout_policy of this TaskDef.


        :param timeout_policy: The timeout_policy of this TaskDef.  # noqa: E501
        :type: str
        """
        allowed_values = ["RETRY", "TIME_OUT_WF", "ALERT_ONLY"]  # noqa: E501
        if timeout_policy not in allowed_values:
            raise ValueError(
                "Invalid value for `timeout_policy` ({0}), must be one of {1}"  # noqa: E501
                .format(timeout_policy, allowed_values)
            )

        self._timeout_policy = timeout_policy

    @property
    def retry_logic(self):
        """Gets the retry_logic of this TaskDef.  # noqa: E501


        :return: The retry_logic of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._retry_logic

    @retry_logic.setter
    def retry_logic(self, retry_logic):
        """Sets the retry_logic of this TaskDef.


        :param retry_logic: The retry_logic of this TaskDef.  # noqa: E501
        :type: str
        """
        allowed_values = ["FIXED", "EXPONENTIAL_BACKOFF", "LINEAR_BACKOFF"]  # noqa: E501
        if retry_logic not in allowed_values:
            raise ValueError(
                "Invalid value for `retry_logic` ({0}), must be one of {1}"  # noqa: E501
                .format(retry_logic, allowed_values)
            )

        self._retry_logic = retry_logic

    @property
    def retry_delay_seconds(self):
        """Gets the retry_delay_seconds of this TaskDef.  # noqa: E501


        :return: The retry_delay_seconds of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._retry_delay_seconds

    @retry_delay_seconds.setter
    def retry_delay_seconds(self, retry_delay_seconds):
        """Sets the retry_delay_seconds of this TaskDef.


        :param retry_delay_seconds: The retry_delay_seconds of this TaskDef.  # noqa: E501
        :type: int
        """

        self._retry_delay_seconds = retry_delay_seconds

    @property
    def response_timeout_seconds(self):
        """Gets the response_timeout_seconds of this TaskDef.  # noqa: E501


        :return: The response_timeout_seconds of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._response_timeout_seconds

    @response_timeout_seconds.setter
    def response_timeout_seconds(self, response_timeout_seconds):
        """Sets the response_timeout_seconds of this TaskDef.


        :param response_timeout_seconds: The response_timeout_seconds of this TaskDef.  # noqa: E501
        :type: int
        """

        self._response_timeout_seconds = response_timeout_seconds

    @property
    def concurrent_exec_limit(self):
        """Gets the concurrent_exec_limit of this TaskDef.  # noqa: E501


        :return: The concurrent_exec_limit of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._concurrent_exec_limit

    @concurrent_exec_limit.setter
    def concurrent_exec_limit(self, concurrent_exec_limit):
        """Sets the concurrent_exec_limit of this TaskDef.


        :param concurrent_exec_limit: The concurrent_exec_limit of this TaskDef.  # noqa: E501
        :type: int
        """

        self._concurrent_exec_limit = concurrent_exec_limit

    @property
    def input_template(self):
        """Gets the input_template of this TaskDef.  # noqa: E501


        :return: The input_template of this TaskDef.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._input_template

    @input_template.setter
    def input_template(self, input_template):
        """Sets the input_template of this TaskDef.


        :param input_template: The input_template of this TaskDef.  # noqa: E501
        :type: dict(str, object)
        """

        self._input_template = input_template

    @property
    def rate_limit_per_frequency(self):
        """Gets the rate_limit_per_frequency of this TaskDef.  # noqa: E501


        :return: The rate_limit_per_frequency of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._rate_limit_per_frequency

    @rate_limit_per_frequency.setter
    def rate_limit_per_frequency(self, rate_limit_per_frequency):
        """Sets the rate_limit_per_frequency of this TaskDef.


        :param rate_limit_per_frequency: The rate_limit_per_frequency of this TaskDef.  # noqa: E501
        :type: int
        """

        self._rate_limit_per_frequency = rate_limit_per_frequency

    @property
    def rate_limit_frequency_in_seconds(self):
        """Gets the rate_limit_frequency_in_seconds of this TaskDef.  # noqa: E501


        :return: The rate_limit_frequency_in_seconds of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._rate_limit_frequency_in_seconds

    @rate_limit_frequency_in_seconds.setter
    def rate_limit_frequency_in_seconds(self, rate_limit_frequency_in_seconds):
        """Sets the rate_limit_frequency_in_seconds of this TaskDef.


        :param rate_limit_frequency_in_seconds: The rate_limit_frequency_in_seconds of this TaskDef.  # noqa: E501
        :type: int
        """

        self._rate_limit_frequency_in_seconds = rate_limit_frequency_in_seconds

    @property
    def isolation_group_id(self):
        """Gets the isolation_group_id of this TaskDef.  # noqa: E501


        :return: The isolation_group_id of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._isolation_group_id

    @isolation_group_id.setter
    def isolation_group_id(self, isolation_group_id):
        """Sets the isolation_group_id of this TaskDef.


        :param isolation_group_id: The isolation_group_id of this TaskDef.  # noqa: E501
        :type: str
        """

        self._isolation_group_id = isolation_group_id

    @property
    def execution_name_space(self):
        """Gets the execution_name_space of this TaskDef.  # noqa: E501


        :return: The execution_name_space of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._execution_name_space

    @execution_name_space.setter
    def execution_name_space(self, execution_name_space):
        """Sets the execution_name_space of this TaskDef.


        :param execution_name_space: The execution_name_space of this TaskDef.  # noqa: E501
        :type: str
        """

        self._execution_name_space = execution_name_space

    @property
    def owner_email(self):
        """Gets the owner_email of this TaskDef.  # noqa: E501


        :return: The owner_email of this TaskDef.  # noqa: E501
        :rtype: str
        """
        return self._owner_email

    @owner_email.setter
    def owner_email(self, owner_email):
        """Sets the owner_email of this TaskDef.


        :param owner_email: The owner_email of this TaskDef.  # noqa: E501
        :type: str
        """

        self._owner_email = owner_email

    @property
    def poll_timeout_seconds(self):
        """Gets the poll_timeout_seconds of this TaskDef.  # noqa: E501


        :return: The poll_timeout_seconds of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._poll_timeout_seconds

    @poll_timeout_seconds.setter
    def poll_timeout_seconds(self, poll_timeout_seconds):
        """Sets the poll_timeout_seconds of this TaskDef.


        :param poll_timeout_seconds: The poll_timeout_seconds of this TaskDef.  # noqa: E501
        :type: int
        """

        self._poll_timeout_seconds = poll_timeout_seconds

    @property
    def backoff_scale_factor(self):
        """Gets the backoff_scale_factor of this TaskDef.  # noqa: E501


        :return: The backoff_scale_factor of this TaskDef.  # noqa: E501
        :rtype: int
        """
        return self._backoff_scale_factor

    @backoff_scale_factor.setter
    def backoff_scale_factor(self, backoff_scale_factor):
        """Sets the backoff_scale_factor of this TaskDef.


        :param backoff_scale_factor: The backoff_scale_factor of this TaskDef.  # noqa: E501
        :type: int
        """

        self._backoff_scale_factor = backoff_scale_factor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskDef, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskDef):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from conductor.client.http.api_client import ApiClient
from conductor.client.http.api.event_resource_api import EventResourceApi
from conductor.client.event.queue.queue_configuration import QueueConfiguration


class EventClient:
    def __init__(self, api_client: ApiClient):
        self.client = EventResourceApi(api_client)

    def delete_queue_configuration(self, queue_configuration: QueueConfiguration) -> None:
        return self.client.delete_queue_config(
            queue_name=queue_configuration.queue_name,
            queue_type=queue_configuration.queue_type,
        )

    def get_kafka_queue_configuration(self, queue_topic: str) -> QueueConfiguration:
        return self.get_queue_configuration(
            queue_type='kafka',
            queue_name=queue_topic,
        )

    def get_queue_configuration(self, queue_type: str, queue_name: str):
        return self.client.get_queue_config(queue_type, queue_name)

    def put_queue_configuration(self, queue_configuration: QueueConfiguration):
        return self.client.put_queue_config(
            body=queue_configuration.get_worker_configuration(),
            queue_name=queue_configuration.queue_name,
            queue_type=queue_configuration.queue_type,
        )



import pprint
import re  # noqa: F401

import six

class WorkflowSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'workflow_type': 'str',
        'version': 'int',
        'workflow_id': 'str',
        'correlation_id': 'str',
        'start_time': 'str',
        'update_time': 'str',
        'end_time': 'str',
        'status': 'str',
        'input': 'str',
        'output': 'str',
        'reason_for_incompletion': 'str',
        'execution_time': 'int',
        'event': 'str',
        'failed_reference_task_names': 'str',
        'external_input_payload_storage_path': 'str',
        'external_output_payload_storage_path': 'str',
        'priority': 'int',
        'created_by': 'str',
        'output_size': 'int',
        'input_size': 'int'
    }

    attribute_map = {
        'workflow_type': 'workflowType',
        'version': 'version',
        'workflow_id': 'workflowId',
        'correlation_id': 'correlationId',
        'start_time': 'startTime',
        'update_time': 'updateTime',
        'end_time': 'endTime',
        'status': 'status',
        'input': 'input',
        'output': 'output',
        'reason_for_incompletion': 'reasonForIncompletion',
        'execution_time': 'executionTime',
        'event': 'event',
        'failed_reference_task_names': 'failedReferenceTaskNames',
        'external_input_payload_storage_path': 'externalInputPayloadStoragePath',
        'external_output_payload_storage_path': 'externalOutputPayloadStoragePath',
        'priority': 'priority',
        'created_by': 'createdBy',
        'output_size': 'outputSize',
        'input_size': 'inputSize'
    }

    def __init__(self, workflow_type=None, version=None, workflow_id=None, correlation_id=None, start_time=None, update_time=None, end_time=None, status=None, input=None, output=None, reason_for_incompletion=None, execution_time=None, event=None, failed_reference_task_names=None, external_input_payload_storage_path=None, external_output_payload_storage_path=None, priority=None, created_by=None, output_size=None, input_size=None):  # noqa: E501
        """WorkflowSummary - a model defined in Swagger"""  # noqa: E501
        self._workflow_type = None
        self._version = None
        self._workflow_id = None
        self._correlation_id = None
        self._start_time = None
        self._update_time = None
        self._end_time = None
        self._status = None
        self._input = None
        self._output = None
        self._reason_for_incompletion = None
        self._execution_time = None
        self._event = None
        self._failed_reference_task_names = None
        self._external_input_payload_storage_path = None
        self._external_output_payload_storage_path = None
        self._priority = None
        self._created_by = None
        self._output_size = None
        self._input_size = None
        self.discriminator = None
        if workflow_type is not None:
            self.workflow_type = workflow_type
        if version is not None:
            self.version = version
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if correlation_id is not None:
            self.correlation_id = correlation_id
        if start_time is not None:
            self.start_time = start_time
        if update_time is not None:
            self.update_time = update_time
        if end_time is not None:
            self.end_time = end_time
        if status is not None:
            self.status = status
        if input is not None:
            self.input = input
        if output is not None:
            self.output = output
        if reason_for_incompletion is not None:
            self.reason_for_incompletion = reason_for_incompletion
        if execution_time is not None:
            self.execution_time = execution_time
        if event is not None:
            self.event = event
        if failed_reference_task_names is not None:
            self.failed_reference_task_names = failed_reference_task_names
        if external_input_payload_storage_path is not None:
            self.external_input_payload_storage_path = external_input_payload_storage_path
        if external_output_payload_storage_path is not None:
            self.external_output_payload_storage_path = external_output_payload_storage_path
        if priority is not None:
            self.priority = priority
        if created_by is not None:
            self.created_by = created_by
        if output_size is not None:
            self.output_size = output_size
        if input_size is not None:
            self.input_size = input_size

    @property
    def workflow_type(self):
        """Gets the workflow_type of this WorkflowSummary.  # noqa: E501


        :return: The workflow_type of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._workflow_type

    @workflow_type.setter
    def workflow_type(self, workflow_type):
        """Sets the workflow_type of this WorkflowSummary.


        :param workflow_type: The workflow_type of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._workflow_type = workflow_type

    @property
    def version(self):
        """Gets the version of this WorkflowSummary.  # noqa: E501


        :return: The version of this WorkflowSummary.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this WorkflowSummary.


        :param version: The version of this WorkflowSummary.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def workflow_id(self):
        """Gets the workflow_id of this WorkflowSummary.  # noqa: E501


        :return: The workflow_id of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this WorkflowSummary.


        :param workflow_id: The workflow_id of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    @property
    def correlation_id(self):
        """Gets the correlation_id of this WorkflowSummary.  # noqa: E501


        :return: The correlation_id of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """Sets the correlation_id of this WorkflowSummary.


        :param correlation_id: The correlation_id of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._correlation_id = correlation_id

    @property
    def start_time(self):
        """Gets the start_time of this WorkflowSummary.  # noqa: E501


        :return: The start_time of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this WorkflowSummary.


        :param start_time: The start_time of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._start_time = start_time

    @property
    def update_time(self):
        """Gets the update_time of this WorkflowSummary.  # noqa: E501


        :return: The update_time of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this WorkflowSummary.


        :param update_time: The update_time of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def end_time(self):
        """Gets the end_time of this WorkflowSummary.  # noqa: E501


        :return: The end_time of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this WorkflowSummary.


        :param end_time: The end_time of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._end_time = end_time

    @property
    def status(self):
        """Gets the status of this WorkflowSummary.  # noqa: E501


        :return: The status of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WorkflowSummary.


        :param status: The status of this WorkflowSummary.  # noqa: E501
        :type: str
        """
        allowed_values = ["RUNNING", "COMPLETED", "FAILED", "TIMED_OUT", "TERMINATED", "PAUSED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def input(self):
        """Gets the input of this WorkflowSummary.  # noqa: E501


        :return: The input of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this WorkflowSummary.


        :param input: The input of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._input = input

    @property
    def output(self):
        """Gets the output of this WorkflowSummary.  # noqa: E501


        :return: The output of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._output

    @output.setter
    def output(self, output):
        """Sets the output of this WorkflowSummary.


        :param output: The output of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._output = output

    @property
    def reason_for_incompletion(self):
        """Gets the reason_for_incompletion of this WorkflowSummary.  # noqa: E501


        :return: The reason_for_incompletion of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._reason_for_incompletion

    @reason_for_incompletion.setter
    def reason_for_incompletion(self, reason_for_incompletion):
        """Sets the reason_for_incompletion of this WorkflowSummary.


        :param reason_for_incompletion: The reason_for_incompletion of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._reason_for_incompletion = reason_for_incompletion

    @property
    def execution_time(self):
        """Gets the execution_time of this WorkflowSummary.  # noqa: E501


        :return: The execution_time of this WorkflowSummary.  # noqa: E501
        :rtype: int
        """
        return self._execution_time

    @execution_time.setter
    def execution_time(self, execution_time):
        """Sets the execution_time of this WorkflowSummary.


        :param execution_time: The execution_time of this WorkflowSummary.  # noqa: E501
        :type: int
        """

        self._execution_time = execution_time

    @property
    def event(self):
        """Gets the event of this WorkflowSummary.  # noqa: E501


        :return: The event of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this WorkflowSummary.


        :param event: The event of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._event = event

    @property
    def failed_reference_task_names(self):
        """Gets the failed_reference_task_names of this WorkflowSummary.  # noqa: E501


        :return: The failed_reference_task_names of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._failed_reference_task_names

    @failed_reference_task_names.setter
    def failed_reference_task_names(self, failed_reference_task_names):
        """Sets the failed_reference_task_names of this WorkflowSummary.


        :param failed_reference_task_names: The failed_reference_task_names of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._failed_reference_task_names = failed_reference_task_names

    @property
    def external_input_payload_storage_path(self):
        """Gets the external_input_payload_storage_path of this WorkflowSummary.  # noqa: E501


        :return: The external_input_payload_storage_path of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._external_input_payload_storage_path

    @external_input_payload_storage_path.setter
    def external_input_payload_storage_path(self, external_input_payload_storage_path):
        """Sets the external_input_payload_storage_path of this WorkflowSummary.


        :param external_input_payload_storage_path: The external_input_payload_storage_path of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._external_input_payload_storage_path = external_input_payload_storage_path

    @property
    def external_output_payload_storage_path(self):
        """Gets the external_output_payload_storage_path of this WorkflowSummary.  # noqa: E501


        :return: The external_output_payload_storage_path of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._external_output_payload_storage_path

    @external_output_payload_storage_path.setter
    def external_output_payload_storage_path(self, external_output_payload_storage_path):
        """Sets the external_output_payload_storage_path of this WorkflowSummary.


        :param external_output_payload_storage_path: The external_output_payload_storage_path of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._external_output_payload_storage_path = external_output_payload_storage_path

    @property
    def priority(self):
        """Gets the priority of this WorkflowSummary.  # noqa: E501


        :return: The priority of this WorkflowSummary.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this WorkflowSummary.


        :param priority: The priority of this WorkflowSummary.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def created_by(self):
        """Gets the created_by of this WorkflowSummary.  # noqa: E501


        :return: The created_by of this WorkflowSummary.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this WorkflowSummary.


        :param created_by: The created_by of this WorkflowSummary.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def output_size(self):
        """Gets the output_size of this WorkflowSummary.  # noqa: E501


        :return: The output_size of this WorkflowSummary.  # noqa: E501
        :rtype: int
        """
        return self._output_size

    @output_size.setter
    def output_size(self, output_size):
        """Sets the output_size of this WorkflowSummary.


        :param output_size: The output_size of this WorkflowSummary.  # noqa: E501
        :type: int
        """

        self._output_size = output_size

    @property
    def input_size(self):
        """Gets the input_size of this WorkflowSummary.  # noqa: E501


        :return: The input_size of this WorkflowSummary.  # noqa: E501
        :rtype: int
        """
        return self._input_size

    @input_size.setter
    def input_size(self, input_size):
        """Sets the input_size of this WorkflowSummary.


        :param input_size: The input_size of this WorkflowSummary.  # noqa: E501
        :type: int
        """

        self._input_size = input_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from enum import Enum


class TaskType(str, Enum):
    SIMPLE = 'SIMPLE'
    DYNAMIC = 'DYNAMIC'
    FORK_JOIN = 'FORK_JOIN'
    FORK_JOIN_DYNAMIC = 'FORK_JOIN_DYNAMIC'
    DECISION = 'DECISION'
    SWITCH = 'SWITCH'
    JOIN = 'JOIN'
    DO_WHILE = 'DO_WHILE'
    SUB_WORKFLOW = 'SUB_WORKFLOW'
    START_WORKFLOW = 'START_WORKFLOW'
    EVENT = 'EVENT'
    WAIT = 'WAIT'
    HUMAN = 'HUMAN'
    USER_DEFINED = 'USER_DEFINED'
    HTTP = 'HTTP'
    LAMBDA = 'LAMBDA'
    INLINE = 'INLINE'
    EXCLUSIVE_JOIN = 'EXCLUSIVE_JOIN'
    TERMINATE = 'TERMINATE'
    KAFKA_PUBLISH = 'KAFKA_PUBLISH'
    JSON_JQ_TRANSFORM = 'JSON_JQ_TRANSFORM'
    SET_VARIABLE = 'SET_VARIABLE'



from conductor.client.http.models.workflow_task import WorkflowTask
from conductor.client.workflow.task.task import TaskInterface
from conductor.client.workflow.task.task_type import TaskType
from copy import deepcopy
from typing import List
from typing_extensions import Self


class JoinTask(TaskInterface):
    def __init__(self, task_ref_name: str, join_on: List[str] = None) -> Self:
        super().__init__(
            task_reference_name=task_ref_name,
            task_type=TaskType.JOIN
        )
        self._join_on = deepcopy(join_on)

    def to_workflow_task(self) -> WorkflowTask:
        workflow = super().to_workflow_task()
        workflow.join_on = self._join_on
        return workflow



class Token(object):
    swagger_types = {
        'token': 'str'
    }

    attribute_map = {
        'token': 'token'
    }

    def __init__(self, token: str = None):
        self.token = None
        if token is not None:
            self.token = token

    @property
    def token(self) -> str:
        return self._token

    @token.setter
    def token(self, token: str):
        self._token = token



from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six
import socket

from conductor.client.http.api_client import ApiClient


class TaskResourceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def all(self, **kwargs):  # noqa: E501
        """Get the details about each queue  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.all(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: dict(str, int)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.all_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.all_with_http_info(**kwargs)  # noqa: E501
            return data

    def all_with_http_info(self, **kwargs):  # noqa: E501
        """Get the details about each queue  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.all_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: dict(str, int)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method all" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/queue/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, int)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def all_verbose(self, **kwargs):  # noqa: E501
        """Get the details about each queue  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.all_verbose(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: dict(str, dict(str, dict(str, int)))
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.all_verbose_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.all_verbose_with_http_info(**kwargs)  # noqa: E501
            return data

    def all_verbose_with_http_info(self, **kwargs):  # noqa: E501
        """Get the details about each queue  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.all_verbose_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: dict(str, dict(str, dict(str, int)))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method all_verbose" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/queue/all/verbose', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, dict(str, dict(str, int)))',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def batch_poll(self, tasktype, **kwargs):  # noqa: E501
        """Batch poll for a task of a certain type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.batch_poll(tasktype, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tasktype: (required)
        :param str workerid:
        :param str domain:
        :param int count:
        :param int timeout:
        :return: list[Task]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.batch_poll_with_http_info(tasktype, **kwargs)  # noqa: E501
        else:
            (data) = self.batch_poll_with_http_info(tasktype, **kwargs)  # noqa: E501
            return data

    def batch_poll_with_http_info(self, tasktype, **kwargs):  # noqa: E501
        """Batch poll for a task of a certain type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.batch_poll_with_http_info(tasktype, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tasktype: (required)
        :param str workerid:
        :param str domain:
        :param int count:
        :param int timeout:
        :return: list[Task]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['tasktype', 'workerid', 'domain', 'count', 'timeout']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method batch_poll" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tasktype' is set
        if ('tasktype' not in params or
                params['tasktype'] is None):
            raise ValueError("Missing the required parameter `tasktype` when calling `batch_poll`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tasktype' in params:
            path_params['tasktype'] = params['tasktype']  # noqa: E501

        query_params = []
        if 'workerid' in params:
            query_params.append(('workerid', params['workerid']))  # noqa: E501
        if 'domain' in params:
            query_params.append(('domain', params['domain']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'timeout' in params:
            query_params.append(('timeout', params['timeout']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/poll/batch/{tasktype}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Task]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_poll_data(self, **kwargs):  # noqa: E501
        """Get the last poll data for all task types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_poll_data(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[PollData]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_poll_data_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_poll_data_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_poll_data_with_http_info(self, **kwargs):  # noqa: E501
        """Get the last poll data for all task types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_poll_data_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[PollData]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_poll_data" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/queue/polldata/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PollData]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_external_storage_location1(self, path, operation, payload_type, **kwargs):  # noqa: E501
        """Get the external uri where the task payload is to be stored  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_external_storage_location1(path, operation, payload_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str path: (required)
        :param str operation: (required)
        :param str payload_type: (required)
        :return: ExternalStorageLocation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_external_storage_location1_with_http_info(path, operation, payload_type, **kwargs)  # noqa: E501
        else:
            (data) = self.get_external_storage_location1_with_http_info(path, operation, payload_type, **kwargs)  # noqa: E501
            return data

    def get_external_storage_location1_with_http_info(self, path, operation, payload_type, **kwargs):  # noqa: E501
        """Get the external uri where the task payload is to be stored  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_external_storage_location1_with_http_info(path, operation, payload_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str path: (required)
        :param str operation: (required)
        :param str payload_type: (required)
        :return: ExternalStorageLocation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'operation', 'payload_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_external_storage_location1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params or
                params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `get_external_storage_location1`")  # noqa: E501
        # verify the required parameter 'operation' is set
        if ('operation' not in params or
                params['operation'] is None):
            raise ValueError("Missing the required parameter `operation` when calling `get_external_storage_location1`")  # noqa: E501
        # verify the required parameter 'payload_type' is set
        if ('payload_type' not in params or
                params['payload_type'] is None):
            raise ValueError("Missing the required parameter `payload_type` when calling `get_external_storage_location1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))  # noqa: E501
        if 'operation' in params:
            query_params.append(('operation', params['operation']))  # noqa: E501
        if 'payload_type' in params:
            query_params.append(('payloadType', params['payload_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/externalstoragelocation', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ExternalStorageLocation',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_poll_data(self, task_type, **kwargs):  # noqa: E501
        """Get the last poll data for a given task type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_poll_data(task_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_type: (required)
        :return: list[PollData]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_poll_data_with_http_info(task_type, **kwargs)  # noqa: E501
        else:
            (data) = self.get_poll_data_with_http_info(task_type, **kwargs)  # noqa: E501
            return data

    def get_poll_data_with_http_info(self, task_type, **kwargs):  # noqa: E501
        """Get the last poll data for a given task type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_poll_data_with_http_info(task_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_type: (required)
        :return: list[PollData]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['task_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_poll_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'task_type' is set
        if ('task_type' not in params or
                params['task_type'] is None):
            raise ValueError("Missing the required parameter `task_type` when calling `get_poll_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'task_type' in params:
            query_params.append(('taskType', params['task_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/queue/polldata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PollData]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_task(self, task_id, **kwargs):  # noqa: E501
        """Get task by Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_task(task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_id: (required)
        :return: Task
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_task_with_http_info(task_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_task_with_http_info(task_id, **kwargs)  # noqa: E501
            return data

    def get_task_with_http_info(self, task_id, **kwargs):  # noqa: E501
        """Get task by Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_task_with_http_info(task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_id: (required)
        :return: Task
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['task_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_task" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'task_id' is set
        if ('task_id' not in params or
                params['task_id'] is None):
            raise ValueError("Missing the required parameter `task_id` when calling `get_task`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_id' in params:
            path_params['taskId'] = params['task_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/{taskId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Task',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_task_logs(self, task_id, **kwargs):  # noqa: E501
        """Get Task Execution Logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_task_logs(task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_id: (required)
        :return: list[TaskExecLog]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_task_logs_with_http_info(task_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_task_logs_with_http_info(task_id, **kwargs)  # noqa: E501
            return data

    def get_task_logs_with_http_info(self, task_id, **kwargs):  # noqa: E501
        """Get Task Execution Logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_task_logs_with_http_info(task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_id: (required)
        :return: list[TaskExecLog]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['task_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_task_logs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'task_id' is set
        if ('task_id' not in params or
                params['task_id'] is None):
            raise ValueError("Missing the required parameter `task_id` when calling `get_task_logs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_id' in params:
            path_params['taskId'] = params['task_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/{taskId}/log', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TaskExecLog]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def log(self, body, task_id, **kwargs):  # noqa: E501
        """Log Task Execution Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.log(body, task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: (required)
        :param str task_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.log_with_http_info(body, task_id, **kwargs)  # noqa: E501
        else:
            (data) = self.log_with_http_info(body, task_id, **kwargs)  # noqa: E501
            return data

    def log_with_http_info(self, body, task_id, **kwargs):  # noqa: E501
        """Log Task Execution Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.log_with_http_info(body, task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: (required)
        :param str task_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'task_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method log" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `log`")  # noqa: E501
        # verify the required parameter 'task_id' is set
        if ('task_id' not in params or
                params['task_id'] is None):
            raise ValueError("Missing the required parameter `task_id` when calling `log`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_id' in params:
            path_params['taskId'] = params['task_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/{taskId}/log', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def poll(self, tasktype, **kwargs):  # noqa: E501
        """Poll for a task of a certain type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.poll(tasktype, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tasktype: (required)
        :param str workerid:
        :param str domain:
        :return: Task
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.poll_with_http_info(tasktype, **kwargs)  # noqa: E501
        else:
            (data) = self.poll_with_http_info(tasktype, **kwargs)  # noqa: E501
            return data

    def poll_with_http_info(self, tasktype, **kwargs):  # noqa: E501
        """Poll for a task of a certain type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.poll_with_http_info(tasktype, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tasktype: (required)
        :param str workerid:
        :param str domain:
        :return: Task
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['tasktype', 'workerid', 'domain']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method poll" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tasktype' is set
        if ('tasktype' not in params or
                params['tasktype'] is None):
            raise ValueError("Missing the required parameter `tasktype` when calling `poll`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tasktype' in params:
            path_params['tasktype'] = params['tasktype']  # noqa: E501

        query_params = []
        if 'workerid' in params:
            query_params.append(('workerid', params['workerid']))  # noqa: E501
        if 'domain' in params:
            query_params.append(('domain', params['domain']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/poll/{tasktype}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Task',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def requeue_pending_task(self, task_type, **kwargs):  # noqa: E501
        """Requeue pending tasks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.requeue_pending_task(task_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_type: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.requeue_pending_task_with_http_info(task_type, **kwargs)  # noqa: E501
        else:
            (data) = self.requeue_pending_task_with_http_info(task_type, **kwargs)  # noqa: E501
            return data

    def requeue_pending_task_with_http_info(self, task_type, **kwargs):  # noqa: E501
        """Requeue pending tasks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.requeue_pending_task_with_http_info(task_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_type: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['task_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method requeue_pending_task" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'task_type' is set
        if ('task_type' not in params or
                params['task_type'] is None):
            raise ValueError("Missing the required parameter `task_type` when calling `requeue_pending_task`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_type' in params:
            path_params['taskType'] = params['task_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/queue/requeue/{taskType}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search1(self, **kwargs):  # noqa: E501
        """Search for tasks based in payload and other parameters  # noqa: E501

        use sort options as sort=<field>:ASC|DESC e.g. sort=name&sort=workflowId:DESC. If order is not specified, defaults to ASC  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search1(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start:
        :param int size:
        :param str sort:
        :param str free_text:
        :param str query:
        :return: SearchResultTaskSummary
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search1_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.search1_with_http_info(**kwargs)  # noqa: E501
            return data

    def search1_with_http_info(self, **kwargs):  # noqa: E501
        """Search for tasks based in payload and other parameters  # noqa: E501

        use sort options as sort=<field>:ASC|DESC e.g. sort=name&sort=workflowId:DESC. If order is not specified, defaults to ASC  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start:
        :param int size:
        :param str sort:
        :param str free_text:
        :param str query:
        :return: SearchResultTaskSummary
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'size', 'sort', 'free_text', 'query']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search1" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
        if 'free_text' in params:
            query_params.append(('freeText', params['free_text']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchResultTaskSummary',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_v21(self, **kwargs):  # noqa: E501
        """Search for tasks based in payload and other parameters  # noqa: E501

        use sort options as sort=<field>:ASC|DESC e.g. sort=name&sort=workflowId:DESC. If order is not specified, defaults to ASC  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_v21(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start:
        :param int size:
        :param str sort:
        :param str free_text:
        :param str query:
        :return: SearchResultTask
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_v21_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.search_v21_with_http_info(**kwargs)  # noqa: E501
            return data

    def search_v21_with_http_info(self, **kwargs):  # noqa: E501
        """Search for tasks based in payload and other parameters  # noqa: E501

        use sort options as sort=<field>:ASC|DESC e.g. sort=name&sort=workflowId:DESC. If order is not specified, defaults to ASC  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_v21_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start:
        :param int size:
        :param str sort:
        :param str free_text:
        :param str query:
        :return: SearchResultTask
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'size', 'sort', 'free_text', 'query']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_v21" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
        if 'free_text' in params:
            query_params.append(('freeText', params['free_text']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/search-v2', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchResultTask',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def size(self, **kwargs):  # noqa: E501
        """Get Task type queue sizes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.size(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] task_type:
        :return: dict(str, int)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.size_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.size_with_http_info(**kwargs)  # noqa: E501
            return data

    def size_with_http_info(self, **kwargs):  # noqa: E501
        """Get Task type queue sizes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.size_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] task_type:
        :return: dict(str, int)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['task_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method size" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'task_type' in params:
            query_params.append(('taskType', params['task_type']))  # noqa: E501
            collection_formats['taskType'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/queue/sizes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, int)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_task(self, body, **kwargs):  # noqa: E501
        """Update a task  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_task(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TaskResult body: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_task_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_task_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_task_with_http_info(self, body, **kwargs):  # noqa: E501
        """Update a task  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_task_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TaskResult body: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_task" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_task`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_task1(self, body, workflow_id, task_ref_name, status, **kwargs):  # noqa: E501
        """Update a task By Ref Name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_task1(body, workflow_id, task_ref_name, status, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param dict(str, object) body: (required)
        :param str workflow_id: (required)
        :param str task_ref_name: (required)
        :param str status: (required)
        :param str workerid:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_task1_with_http_info(body, workflow_id, task_ref_name, status, **kwargs)  # noqa: E501
        else:
            (data) = self.update_task1_with_http_info(body, workflow_id, task_ref_name, status, **kwargs)  # noqa: E501
            return data

    def update_task1_with_http_info(self, body, workflow_id, task_ref_name, status, **kwargs):  # noqa: E501
        """Update a task By Ref Name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_task1_with_http_info(body, workflow_id, task_ref_name, status, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param dict(str, object) body: (required)
        :param str workflow_id: (required)
        :param str task_ref_name: (required)
        :param str status: (required)
        :param str workerid:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'workflow_id', 'task_ref_name', 'status']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_task1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_task1`")  # noqa: E501
        # verify the required parameter 'workflow_id' is set
        if ('workflow_id' not in params or
                params['workflow_id'] is None):
            raise ValueError("Missing the required parameter `workflow_id` when calling `update_task1`")  # noqa: E501
        # verify the required parameter 'task_ref_name' is set
        if ('task_ref_name' not in params or
                params['task_ref_name'] is None):
            raise ValueError("Missing the required parameter `task_ref_name` when calling `update_task1`")  # noqa: E501
        # verify the required parameter 'status' is set
        if ('status' not in params or
                params['status'] is None):
            raise ValueError("Missing the required parameter `status` when calling `update_task1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_id' in params:
            path_params['workflowId'] = params['workflow_id']  # noqa: E501
        if 'task_ref_name' in params:
            path_params['taskRefName'] = params['task_ref_name']  # noqa: E501
        if 'status' in params:
            path_params['status'] = params['status']  # noqa: E501

        query_params = []
        
        if 'workerid' not in params:
            params['workerid'] = socket.gethostname()
        query_params.append(('workerid', params['workerid']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tasks/{workflowId}/{taskRefName}/{status}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from conductor.client.http.models.workflow_task import WorkflowTask
from conductor.client.workflow.task.task import TaskInterface, get_task_interface_list_as_workflow_task_list
from conductor.client.workflow.task.task_type import TaskType
from copy import deepcopy
from enum import Enum
from typing import List
from typing_extensions import Self


class EvaluatorType(str, Enum):
    JAVASCRIPT = "javascript",
    VALUE_PARAM = "value-param"


class SwitchTask(TaskInterface):
    def __init__(self, task_ref_name: str, case_expression: str, use_javascript: bool = False) -> Self:
        super().__init__(
            task_reference_name=task_ref_name,
            task_type=TaskType.SWITCH,
        )
        self._default_case = None
        self._decision_cases = {}
        self._expression = deepcopy(case_expression)
        self._use_javascript = deepcopy(use_javascript)

    def switch_case(self, case_name: str, tasks: List[TaskInterface]) -> Self:
        if isinstance(tasks, List):
            self._decision_cases[case_name] = deepcopy(tasks)
        else:
            self._decision_cases[case_name] = [deepcopy(tasks)]
        return self

    def default_case(self, tasks: List[TaskInterface]) -> Self:
        if isinstance(tasks, List):
            self._default_case = deepcopy(tasks)
        else:
            self._default_case = [deepcopy(tasks)]
        return self

    def to_workflow_task(self) -> WorkflowTask:
        workflow = super().to_workflow_task()
        if self._use_javascript:
            workflow.evaluator_type = EvaluatorType.JAVASCRIPT
            workflow.expression = self._expression
        else:
            workflow.evaluator_type = EvaluatorType.VALUE_PARAM
            workflow.input_parameters['switchCaseValue'] = self._expression
            workflow.expression = 'switchCaseValue'
        workflow.decision_cases = {}
        for case_value, tasks in self._decision_cases.items():
            workflow.decision_cases[case_value] = get_task_interface_list_as_workflow_task_list(
                *tasks,
            )
        if self._default_case is None:
            self._default_case = []
        workflow.default_case = get_task_interface_list_as_workflow_task_list(
            *self._default_case
        )
        return workflow



from conductor.client.event.queue.queue_configuration import QueueConfiguration
from conductor.client.event.queue.queue_worker_configuration import QueueWorkerConfiguration
from typing import Any, Dict


class KafkaQueueConfiguration(QueueConfiguration):
    def __init__(self, queue_topic_name: str):
        super().__init__(queue_topic_name, 'kafka')

    def get_worker_configuration(self) -> Dict[str, Any]:
        worker_configuration = {}
        for required_key in ['consumer', 'producer']:
            if required_key not in self.worker_configuration:
                raise RuntimeError(f'required key not present: {required_key}')
        for key, value in self.worker_configuration.items():
            worker_configuration[key] = value.configuration
        return worker_configuration


class KafkaConsumerConfiguration(QueueWorkerConfiguration):
    def __init__(self, bootstrap_servers_config: str):
        super().__init__()
        super().add_configuration(
            key='bootstrap.servers',
            value=bootstrap_servers_config
        )


class KafkaProducerConfiguration(QueueWorkerConfiguration):
    def __init__(self, bootstrap_servers_config: str):
        super().__init__()
        super().add_configuration(
            key='bootstrap.servers',
            value=bootstrap_servers_config
        )



from conductor.client.http.models.workflow_def import WorkflowDef
from conductor.client.http.models.workflow_task import WorkflowTask
from conductor.client.workflow.executor.workflow_executor import WorkflowExecutor
from conductor.client.workflow.task.task import TaskInterface
from conductor.client.workflow.task.timeout_policy import TimeoutPolicy
from conductor.client.http.models import *
from copy import deepcopy
from typing import Any, Dict, List
from typing_extensions import Self


class ConductorWorkflow:
    SCHEMA_VERSION = 2

    def __init__(self,
                 executor: WorkflowExecutor,
                 name: str,
                 version: int = None,
                 description: str = None) -> Self:
        self._executor = executor
        self.name = name
        self.version = version
        self.description = description
        self._tasks = []
        self._owner_email = None
        self._timeout_policy = None
        self._timeout_seconds = 60
        self._failure_workflow = ''
        self._input_parameters = []
        self._output_parameters = {}
        self._input_template = {}
        self._variables = {}
        self._restartable = True

    @property
    def name(self) -> str:
        return self._name

    @name.setter
    def name(self, name: str) -> None:
        if not isinstance(name, str):
            raise Exception('invalid type')
        self._name = deepcopy(name)

    @property
    def version(self) -> int:
        return self._version

    @version.setter
    def version(self, version: int) -> None:
        if version != None and not isinstance(version, int):
            raise Exception('invalid type')
        self._version = deepcopy(version)

    @property
    def description(self) -> str:
        return self._description

    @description.setter
    def description(self, description: str) -> None:
        if description != None and not isinstance(description, str):
            raise Exception('invalid type')
        self._description = deepcopy(description)

    def timeout_policy(self, timeout_policy: TimeoutPolicy) -> Self:
        if not isinstance(timeout_policy, TimeoutPolicy):
            raise Exception('invalid type')
        self._timeout_policy = deepcopy(timeout_policy)
        return self

    def timeout_seconds(self, timeout_seconds: int) -> Self:
        if not isinstance(timeout_seconds, int):
            raise Exception('invalid type')
        self._timeout_seconds = deepcopy(timeout_seconds)
        return self

    def owner_email(self, owner_email: str) -> Self:
        if not isinstance(owner_email, str):
            raise Exception('invalid type')
        self._owner_email = deepcopy(owner_email)
        return self

    # Name of the workflow to execute when this workflow fails.
    # Failure workflows can be used for handling compensation logic
    def failure_workflow(self, failure_workflow: str) -> Self:
        if not isinstance(failure_workflow, str):
            raise Exception('invalid type')
        self._failure_workflow = deepcopy(failure_workflow)
        return self

    # If the workflow can be restarted after it has reached terminal state.
    # Set this to false if restarting workflow can have side effects
    def restartable(self, restartable: bool) -> Self:
        if not isinstance(restartable, bool):
            raise Exception('invalid type')
        self._restartable = deepcopy(restartable)
        return self

    # Workflow output follows similar structure as task input
    # See https://conductor.netflix.com/how-tos/Tasks/task-inputs.html for more details
    def output_parameters(self, output_parameters: Dict[str, Any]) -> Self:
        if output_parameters == None:
            self._output_parameters = {}
            return
        if not isinstance(output_parameters, dict):
            raise Exception('invalid type')
        for key in output_parameters.keys():
            if not isinstance(key, str):
                raise Exception('invalid type')
        self._output_parameters = deepcopy(output_parameters)
        return self

    # InputTemplate template input to the workflow.  Can have combination of variables (e.g. ${workflow.input.abc}) and static values
    def input_template(self, input_template: Dict[str, Any]) -> Self:
        if input_template == None:
            self._output_parameters = {}
            return
        if not isinstance(input_template, dict):
            raise Exception('invalid type')
        for key in input_template.keys():
            if not isinstance(key, str):
                raise Exception('invalid type')
        self._output_parameters = deepcopy(input_template)
        return self

    # Variables are set using SET_VARIABLE task. Excellent way to maintain business state
    # e.g. Variables can maintain business/user specific states which can be queried and inspected to find out the state of the workflow
    def variables(self, variables: Dict[str, Any]) -> Self:
        if variables == None:
            self._output_parameters = {}
            return
        if not isinstance(variables, dict):
            raise Exception('invalid type')
        for key in variables.keys():
            if not isinstance(key, str):
                raise Exception('invalid type')
        self._output_parameters = deepcopy(variables)
        return self

    # List of the input parameters to the workflow. Usage: documentation ONLY
    def input_parameters(self, input_parameters: List[str]) -> Self:
        if not isinstance(input_parameters, list):
            raise Exception('invalid type')
        for input_parameter in input_parameters:
            if not isinstance(input_parameter, str):
                raise Exception('invalid type')
        self._input_parameters = deepcopy(input_parameters)
        return self

    # Register the workflow definition with the server. If overwrite is set, the definition on the server will be
    # overwritten. When not set, the call fails if there is any change in the workflow definition between the server
    # and what is being registered.
    def register(self, overwrite: bool):
        return self._executor.register_workflow(
            overwrite=overwrite,
            workflow=self.to_workflow_def(),
        )

    # Executes the workflow inline without registering with the server.  Useful for one-off workflows that need not
    # be registered.
    def start_workflow(self, start_workflow_request: StartWorkflowRequest):
        start_workflow_request.workflow_def = self.to_workflow_def()
        return self._executor.start_workflow(start_workflow_request)

    # Converts the workflow to the JSON serializable format
    def to_workflow_def(self) -> WorkflowDef:
        return WorkflowDef(
            name=self._name,
            description=self._description,
            version=self._version,
            tasks=self.__get_workflow_task_list(),
            input_parameters=self._input_parameters,
            output_parameters=self._output_parameters,
            failure_workflow=self._failure_workflow,
            schema_version=ConductorWorkflow.SCHEMA_VERSION,
            owner_email=self._owner_email,
            timeout_policy=self._timeout_policy,
            timeout_seconds=self._timeout_seconds,
            variables=self._variables,
            input_template=self._input_template,
        )

    def __get_workflow_task_list(self) -> List[WorkflowTask]:
        workflow_task_list = []
        for task in self._tasks:
            converted_task = task.to_workflow_task()
            if isinstance(converted_task, list):
                for subtask in converted_task:
                    workflow_task_list.append(subtask)
            else:
                workflow_task_list.append(converted_task)
        return workflow_task_list

    # Append task with the right shift operator `>>`
    def __rshift__(self, task: TaskInterface) -> Self:
        return self.__add_task(task)

    # Append task
    def add(self, task: TaskInterface) -> Self:
        return self.__add_task(task)

    def __add_task(self, task: TaskInterface) -> Self:
        if not issubclass(type(task), TaskInterface):
            raise Exception('invalid type')
        self._tasks.append(deepcopy(task))
        return self



from enum import Enum


class MetricDocumentation(str, Enum):
    EXTERNAL_PAYLOAD_USED = "Incremented each time external payload storage is used"
    TASK_ACK_ERROR = "Task ack has encountered an exception"
    TASK_ACK_FAILED = "Task ack failed"
    TASK_EXECUTE_ERROR = "Execution error"
    TASK_EXECUTE_TIME = "Time to execute a task"
    TASK_EXECUTION_QUEUE_FULL = "Counter to record execution queue has saturated"
    TASK_PAUSED = "Counter for number of times the task has been polled, when the worker has been paused"
    TASK_POLL = "Incremented each time polling is done"
    TASK_POLL_ERROR = "Client error when polling for a task queue"
    TASK_POLL_TIME = "Time to poll for a batch of tasks"
    TASK_RESULT_SIZE = "Records output payload size of a task"
    TASK_UPDATE_ERROR = "Task status cannot be updated back to server"
    THREAD_UNCAUGHT_EXCEPTION = "thread_uncaught_exceptions"
    WORKFLOW_START_ERROR = "Counter for workflow start errors"
    WORKFLOW_INPUT_SIZE = "Records input payload size of a workflow"
